==> pygame_1.9.6+dfsg.orig.tar.xz: pygame-1.9.6/src_c/doc/time_doc.h <==
/* Auto generated file: with makeref.py .  Docs go in docs/reST/ref/ . */
#define DOC_PYGAMETIME "pygame module for monitoring time"
#define DOC_PYGAMETIMEGETTICKS "get_ticks() -> milliseconds\nget the time in milliseconds"
#define DOC_PYGAMETIMEWAIT "wait(milliseconds) -> time\npause the program for an amount of time"
#define DOC_PYGAMETIMEDELAY "delay(milliseconds) -> time\npause the program for an amount of time"
#define DOC_PYGAMETIMESETTIMER "set_timer(eventid, milliseconds) -> None\nrepeatedly create an event on the event queue"
#define DOC_PYGAMETIMECLOCK "Clock() -> Clock\ncreate an object to help track time"
#define DOC_CLOCKTICK "tick(framerate=0) -> milliseconds\nupdate the clock"
#define DOC_CLOCKTICKBUSYLOOP "tick_busy_loop(framerate=0) -> milliseconds\nupdate the clock"
#define DOC_CLOCKGETTIME "get_time() -> milliseconds\ntime used in the previous tick"
#define DOC_CLOCKGETRAWTIME "get_rawtime() -> milliseconds\nactual time used in the previous tick"
#define DOC_CLOCKGETFPS "get_fps() -> float\ncompute the clock framerate"


/* Docs in a comment... slightly easier to read. */

/*

pygame.time
pygame module for monitoring time

pygame.time.get_ticks
 get_ticks() -> milliseconds
get the time in milliseconds

pygame.time.wait
 wait(milliseconds) -> time
pause the program for an amount of time

pygame.time.delay
 delay(milliseconds) -> time
pause the program for an amount of time

pygame.time.set_timer
 set_timer(eventid, milliseconds) -> None
repeatedly create an event on the event queue

pygame.time.Clock
 Clock() -> Clock
create an object to help track time

pygame.time.Clock.tick
 tick(framerate=0) -> milliseconds
update the clock

pygame.time.Clock.tick_busy_loop
 tick_busy_loop(framerate=0) -> milliseconds
update the clock

pygame.time.Clock.get_time
 get_time() -> milliseconds
time used in the previous tick

pygame.time.Clock.get_rawtime
 get_rawtime() -> milliseconds
actual time used in the previous tick

pygame.time.Clock.get_fps
 get_fps() -> float
compute the clock framerate

*/

==> pygame_2.1.2+dfsg.orig.tar.xz: pygame-2.1.2/src_c/doc/time_doc.h <==
/* Auto generated file: with makeref.py .  Docs go in docs/reST/ref/ . */
#define DOC_PYGAMETIME "pygame module for monitoring time"
#define DOC_PYGAMETIMEGETTICKS "get_ticks() -> milliseconds\nget the time in milliseconds"
#define DOC_PYGAMETIMEWAIT "wait(milliseconds) -> time\npause the program for an amount of time"
#define DOC_PYGAMETIMEDELAY "delay(milliseconds) -> time\npause the program for an amount of time"
#define DOC_PYGAMETIMESETTIMER "set_timer(event, millis) -> None\nset_timer(event, millis, loops=0) -> None\nrepeatedly create an event on the event queue"
#define DOC_PYGAMETIMECLOCK "Clock() -> Clock\ncreate an object to help track time"
#define DOC_CLOCKTICK "tick(framerate=0) -> milliseconds\nupdate the clock"
#define DOC_CLOCKTICKBUSYLOOP "tick_busy_loop(framerate=0) -> milliseconds\nupdate the clock"
#define DOC_CLOCKGETTIME "get_time() -> milliseconds\ntime used in the previous tick"
#define DOC_CLOCKGETRAWTIME "get_rawtime() -> milliseconds\nactual time used in the previous tick"
#define DOC_CLOCKGETFPS "get_fps() -> float\ncompute the clock framerate"


/* Docs in a comment... slightly easier to read. */

/*

pygame.time
pygame module for monitoring time

pygame.time.get_ticks
 get_ticks() -> milliseconds
get the time in milliseconds

pygame.time.wait
 wait(milliseconds) -> time
pause the program for an amount of time

pygame.time.delay
 delay(milliseconds) -> time
pause the program for an amount of time

pygame.time.set_timer
 set_timer(event, millis) -> None
 set_timer(event, millis, loops=0) -> None
repeatedly create an event on the event queue

pygame.time.Clock
 Clock() -> Clock
create an object to help track time

pygame.time.Clock.tick
 tick(framerate=0) -> milliseconds
update the clock

pygame.time.Clock.tick_busy_loop
 tick_busy_loop(framerate=0) -> milliseconds
update the clock

pygame.time.Clock.get_time
 get_time() -> milliseconds
time used in the previous tick

pygame.time.Clock.get_rawtime
 get_rawtime() -> milliseconds
actual time used in the previous tick

pygame.time.Clock.get_fps
 get_fps() -> float
compute the clock framerate

*/
